==> jaguar_resty-1.1.0-dev.tar.gz: lib/src/expect.dart <==
import 'response.dart';

/// Performs a check/validation on [T]
typedef List<Mismatch> Checker<T>(T v);

/// Customizes message of a [Mismatch]
typedef String CustomMismatchMessage<M extends Mismatch>(M mismatch);

/// A mismatch exception
abstract class Mismatch<M> implements Exception {
  /// Used to customize the message
  CustomMismatchMessage<M> customMessage;
}

class EqualityMismatch<T> implements Exception, Mismatch<EqualityMismatch<T>> {
  /// Expected value
  T expected;

  /// Actual value
  T actual;

  CustomMismatchMessage<EqualityMismatch<T>> customMessage;

  EqualityMismatch(this.expected, this.actual, {this.customMessage});

  String toString() => customMessage != null
      ? customMessage(this)
      : "Equality mismatch: Expected: $expected. Found: $actual!";
}

class RangeMismatch<T> implements Exception, Mismatch<RangeMismatch<T>> {
  T lower;

  T higher;

  T actual;

  CustomMismatchMessage<RangeMismatch<T>> customMessage;

  RangeMismatch(this.lower, this.higher, this.actual, {this.customMessage});

  String toString() => customMessage != null
      ? customMessage(this)
      : "Range mismatch: Expected: [$lower, $higher]. Found: $actual!";
}

class MapHasMismatch<T> implements Exception, Mismatch<MapHasMismatch<T>> {
  T key;

  CustomMismatchMessage<MapHasMismatch<T>> customMessage;

  MapHasMismatch(this.key, {this.customMessage});

  String toString() => customMessage != null
      ? customMessage(this)
      : "Map has mismatch: Key $key not found!";
}

Checker<Response> statusCodeIs(int expected) => (Response resp) {
      if (expected != resp.statusCode)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.statusCode,
              customMessage: (m) =>
                  'Expected statuscode ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

Checker<Response> statusCodeIsInRange(int lower, int higher) =>
    (Response resp) {
      if (resp.statusCode < lower || resp.statusCode > higher)
        return <Mismatch>[
          new RangeMismatch(lower, higher, resp.statusCode,
              customMessage: (m) =>
                  'Expected statuscode in range [${m.lower}, ${m.higher} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

Checker<Response> headersHas(String header, [String value]) => (Response resp) {
      if (!resp.headers.containsKey(header))
        return <Mismatch>[
          new MapHasMismatch(header,
              customMessage: (m) => 'Expected header ${m.key} is not found!')
        ];
      if (value != null) {
        if (resp.headers[header] != value)
          return <Mismatch>[
            new EqualityMismatch(value, resp.headers[header],
                customMessage: (m) =>
                    'Header $header is expected to have value ${m.expected} but found ${m.actual}!')
          ];
      }
      return <Mismatch>[];
    };

Checker<Response> bodyIs(String expected) => (Response resp) {
      if (expected != resp.body)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.body,
              customMessage: (m) =>
                  'Expected body ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

Checker<Response> contentTypeIs(String expected) => (Response resp) {
      if (expected != resp.contentType)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.contentType,
              customMessage: (m) =>
                  'Expected body ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

final Checker<Response> contentTypeIsJson = contentTypeIs('application/json');

final Checker<Response> contentTypeIsHtml = contentTypeIs('text/html');

Checker<Response> encodingIs(String expected) => (Response resp) {
      if (expected != resp.encoding)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.encoding,
              customMessage: (m) =>
                  'Expected body ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

==> jaguar_resty-1.1.3.tar.gz: lib/src/expect.dart <==
import 'response.dart';

/// Performs a check/validation on [T]
typedef List<Mismatch> Checker<T>(T v);

/// Customizes message of a [Mismatch]
typedef String CustomMismatchMessage<M extends Mismatch>(M mismatch);

/// A mismatch exception
abstract class Mismatch<M> implements Exception {
  /// Used to customize the message
  CustomMismatchMessage<M> customMessage;
}

class EqualityMismatch<T> implements Exception, Mismatch<EqualityMismatch<T>> {
  /// Expected value
  T expected;

  /// Actual value
  T actual;

  CustomMismatchMessage<EqualityMismatch<T>> customMessage;

  EqualityMismatch(this.expected, this.actual, {this.customMessage});

  String toString() => customMessage != null
      ? customMessage(this)
      : "Equality mismatch: Expected: $expected. Found: $actual!";
}

class RangeMismatch<T> implements Exception, Mismatch<RangeMismatch<T>> {
  T lower;

  T higher;

  T actual;

  CustomMismatchMessage<RangeMismatch<T>> customMessage;

  RangeMismatch(this.lower, this.higher, this.actual, {this.customMessage});

  String toString() => customMessage != null
      ? customMessage(this)
      : "Range mismatch: Expected: [$lower, $higher]. Found: $actual!";
}

class MapHasMismatch<T> implements Exception, Mismatch<MapHasMismatch<T>> {
  T key;

  CustomMismatchMessage<MapHasMismatch<T>> customMessage;

  MapHasMismatch(this.key, {this.customMessage});

  String toString() => customMessage != null
      ? customMessage(this)
      : "Map has mismatch: Key $key not found!";
}

Checker<Response> statusCodeIs(int expected) => (Response resp) {
      if (expected != resp.statusCode)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.statusCode,
              customMessage: (m) =>
                  'Expected statuscode ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

Checker<Response> statusCodeIsInRange(int lower, int higher) =>
    (Response resp) {
      if (resp.statusCode < lower || resp.statusCode > higher)
        return <Mismatch>[
          new RangeMismatch(lower, higher, resp.statusCode,
              customMessage: (m) =>
                  'Expected statuscode in range [${m.lower}, ${m.higher} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

Checker<Response> headersHas(String header, [String value]) => (Response resp) {
      if (!resp.headers.containsKey(header))
        return <Mismatch>[
          new MapHasMismatch(header,
              customMessage: (m) => 'Expected header ${m.key} is not found!')
        ];
      if (value != null) {
        if (resp.headers[header] != value)
          return <Mismatch>[
            new EqualityMismatch(value, resp.headers[header],
                customMessage: (m) =>
                    'Header $header is expected to have value ${m.expected} but found ${m.actual}!')
          ];
      }
      return <Mismatch>[];
    };

Checker<Response> bodyIs(String expected) => (Response resp) {
      if (expected != resp.body)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.body,
              customMessage: (m) =>
                  'Expected body ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

Checker<Response> mimeTypeIs(String expected) => (Response resp) {
      if (expected != resp.mimeType)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.mimeType,
              customMessage: (m) =>
                  'Expected body ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };

final Checker<Response> mimeTypeIsJson = mimeTypeIs('application/json');

final Checker<Response> mimeTypeIsHtml = mimeTypeIs('text/html');

Checker<Response> encodingIs(String expected) => (Response resp) {
      if (expected != resp.encoding)
        return <Mismatch>[
          new EqualityMismatch(expected, resp.encoding,
              customMessage: (m) =>
                  'Expected body ${m.expected} but found ${m.actual}!')
        ];
      return <Mismatch>[];
    };
